-- main.lua
-- jrlf 2010-12-31
-- Simple analogue clock application. Intended for Ben NanoNote, but 
-- should work on other systems. Licensed under GNU GPL 3. See 
-- http://www.gnu.org/licenses/gpl.html.

-- Constants

black = {0}
white = {255}
red   = {255, 0, 0}

-- Utilities

-- ink ( colour --) Set draw colour.

-- A colour is a table of one to four values. A single value puts that
-- value into all the colour records except alpha to make a grayscale.
-- Three values represent RGB with alpha locked to 255. Four is standard
-- RGBA. 

function ink(c)
   if 4 == table.getn(c) then
      love.graphics.setColor(c[1], c[2], c[3], c[4])
   elseif 3 == table.getn(c) then
      love.graphics.setColor(c[1], c[2], c[3], 255)
   elseif 1 == table.getn(c) then
      love.graphics.setColor(c[1], c[1], c[1], 255)
   end
end

-- draw_hands ( p c fore hind r --) Draw analogue clock hand.

-- The 'nlove' program doesn't seem to have OpenGL available, so I need
-- to draw the hands the old fashioned way instead of just rotating 
-- polys into position. Yes, I'm sure this could be much better...

-- p is an X,Y tuple (table) of the location of the clock spindle. c is
-- the colour of the hand. fore and hind are the number of pixels long
-- the hand is be/fore/ and be/hind/ the spindle. r is the radians of
-- rotation. 

function draw_hand(p, c, fore, hind, r)
   ink(c)
   love.graphics.line({
      p[1] + (math.sin(r) * hind),
      p[2] - (math.cos(r) * hind),
      p[1] - (math.sin(r) * fore),
      p[2] + (math.cos(r) * fore)
   })
end

-- LOVE Callbacks

function love.load()

-- The NanoNote doesn't have a mouse, but the cursor still shows. Kill it:

   love.mouse.setVisible(false)
   
-- There is no window system on NanoNote, so full screen it is.

   love.graphics.setMode(320, 240, false, true, 0)
   centre = {love.graphics:getWidth() / 2,
	     love.graphics:getHeight() / 2}

-- Image Resources

   bg = love.graphics.newImage("img/bg.png")
   face = love.graphics.newImage("img/face_analogue_plain.png")
end

function love.draw()
   ink(white)
   love.graphics.draw(
      bg, 
      centre[1] - bg:getWidth() / 2,
      centre[2] - bg:getHeight() / 2)
   love.graphics.draw(
      face,
      centre[1] - face:getWidth() / 2,
      centre[2] - face:getHeight() / 2)

-- Here I get the date and compute the distance around the clock face.

   now = os.date("*t")
   dsec = (math.pi * 2) * (now["sec"] / 60)
   dmin = (math.pi * 2) * (now["min"] / 60)
   dhour = (math.pi * 2) * (
      ((math.fmod(now["hour"], 12) * 60) + now["min"]) / 720)

-- Now I draw the hands. I do the seconds last to make it show up nicely...

   draw_hand(centre, black, 15, 50, dhour)
   draw_hand(centre, black, 30, 80, dmin)
   draw_hand(centre, red, 50, 90, dsec)
end

function love.keyreleased(key, unicode)
   if "escape" == key then love.event.push("q") end
end